# coding: utf-8

"""
    authentik

    Making authentication simple.

    The version of the OpenAPI document: 2025.10.0-rc1
    Contact: hello@goauthentik.io
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from authentik_client.models.settings_request import SettingsRequest

class TestSettingsRequest(unittest.TestCase):
    """SettingsRequest unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> SettingsRequest:
        """Test SettingsRequest
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `SettingsRequest`
        """
        model = SettingsRequest()
        if include_optional:
            return SettingsRequest(
                avatars = '0',
                default_user_change_name = True,
                default_user_change_email = True,
                default_user_change_username = True,
                event_retention = '0',
                reputation_lower_limit = -2147483648,
                reputation_upper_limit = 0,
                footer_links = None,
                gdpr_compliance = True,
                impersonation = True,
                impersonation_require_reason = True,
                default_token_duration = '0',
                default_token_length = 1,
                flags = authentik_client.models.patched_settings_request_flags.PatchedSettingsRequest_flags(
                    policies_buffered_access_view = True, )
            )
        else:
            return SettingsRequest(
                flags = authentik_client.models.patched_settings_request_flags.PatchedSettingsRequest_flags(
                    policies_buffered_access_view = True, ),
        )
        """

    def testSettingsRequest(self):
        """Test SettingsRequest"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
